@@ -15,7 +15,6 @@
 # limitations under the License.
 import os
 
-from oslo_config import cfg
 from oslo_log import log
 
 from monasca_common.kafka import consumer
@@ -62,13 +61,6 @@ class Persister(object):
                 LOG.warning("Some points older than retention policy were dropped")
                 self._data_points = []
                 self._consumer.commit()
-
-            elif cfg.CONF.repositories.ignore_parse_point_error \
-                    and "unable to parse" in ex.message:
-                LOG.warning("Some points were unable to be parsed and were dropped")
-                self._data_points = []
-                self._consumer.commit()
-
             else:
                 LOG.exception("Error writing to database: {}"
                               .format(self._data_points))
